@@ -107,6 +107,7 @@ class ProgressBar(Handler):
             desc=task.additional_info["desc"] if "desc" in task.additional_info else task.name
             logger.info("Creating counter for task {}".format(task.fullname))
             counter = self.manager.counter(total = task.max, desc=desc, bar_format=self.numeric_format, unit=unit, fields=self.get_fields(task))
+            counter.refresh()
             self.dict[task.fullname]=(task, strat, self.compute_number_counters(task, strat), counter)
     def notify_subtasks_started(self, task: Progress):
         strat = self.compute_strategy(task)
@@ -117,6 +118,7 @@ class ProgressBar(Handler):
             desc=task.additional_info["desc"] if "desc" in task.additional_info else task.name
             logger.info("Creating counter for task {}".format(task.fullname))
             counter = self.manager.counter(total = 1.0, desc=desc, bar_format=self.task_format, unit=unit, fields=self.get_fields(task))
+            counter.refresh()
             self.dict[task.fullname]=(task, strat, self.compute_number_counters(task, strat), counter)
     def notify_numeric_update(self, task: Progress):
         while task:
@@ -146,16 +148,17 @@ class ProgressBar(Handler):
             if pds==ProgressBar.DisplayStrategy.REPLACE_SEQUENCE:
                 self.remove_counter(task)
             else:
-                (x, ds, y, counter) = self.dict[task.fullname]
-                if counter:
-                    # st = self.manager.counter(replace=counter, desc=counter.desc, bar_format=self.finished_format, fields=self.get_fields(task))
-                    counter.bar_format=self.finished_format
-                    counter.series=" "
-                    counter.fields=self.get_fields(task)
-                    # st.refresh()
-                    # logger.info("Transforming counter for task {} to status bar".format(task.fullname))
-                    # st.update("  " * task.depth + task.name + "Finished")
-                    # self.dict[task.fullname] = (x, ds, y, st) 
+                if task.fullname in self.dict:
+                    (x, ds, y, counter) = self.dict[task.fullname]
+                    if counter:
+                        # st = self.manager.counter(replace=counter, desc=counter.desc, bar_format=self.finished_format, fields=self.get_fields(task))
+                        counter.bar_format=self.finished_format
+                        counter.series=" "
+                        counter.fields=self.get_fields(task)
+                        # st.refresh()
+                        # logger.info("Transforming counter for task {} to status bar".format(task.fullname))
+                        # st.update("  " * task.depth + task.name + "Finished")
+                        # self.dict[task.fullname] = (x, ds, y, st) 
            
     def remove_counter(self, task: Progress):
         self.notify_numeric_update(task)
